@@ -128,6 +128,8 @@ def checkMask(number, mask):
 #Функция, которая принимает текстовые команды черепахи из задания и переводит их в команды для черепахи из модуля turtle.
 #Применяется в 6 задании. Эта функция сделана для проверки правильности работы вашего алгоритма, не стоит учить эту функцию на ЕГЭ.
 #На вход функция принимает массив из строк алгоритма задания. Вы можете дополнительно указать параметры сетки.
+#Примечание: Код должен передаваться в функцию в виде массива строк. Также вы можете загрузить код из файла, передав в аргумент
+#команду open()
 #Автор: Александр Блинов
 def turtle_6(code, gridSizeX = 16, gridSizeY = 16, gridScale = 20, gridDotSize = 3):
 
@@ -186,3 +188,40 @@ def turtle_6(code, gridSizeX = 16, gridSizeY = 16, gridScale = 20, gridDotSize =
             turtleFuncs[op]()
 
     t.done()
+
+
+#Функция, которая принимает код для исполнителя "Редактор" из задания 12 и возвращает перевод этого кода на Python для дальнейшего использования.
+#Передав True во второй параметр, функция выведет код.
+#Примечание: Код должен передаваться в функцию в виде массива строк. Также вы можете загрузить код из файла, передав в аргумент
+#команду open(). Функция возвращает код также в виде массива.
+#Автор: Александр Блинов
+def toPythonCode_12(s, printCode = False):
+    code = []
+    code.append("string = 'ВАША СТРОКА'")
+    for line in s:
+        l = line.replace("НАЧАЛО", "").replace("заменить С КОНЦА СТРОКИ", "pass #Замена с конца строки ещё не реализована").replace("КОНЕЦ ЕСЛИ", "").replace("КОНЕЦ ПОКА", "").replace("ПОКА", "while").replace("КОНЕЦ", "").replace("ИНАЧЕ ЕСЛИ", "elif").replace("ЕСЛИ", "if").replace("НЕ", "not").replace("ИНАЧЕ", "else:").replace("ИЛИ", "or").replace("И", "and").replace("ТО ", "").replace("\n", "")
+
+        for tokenFound in re.findall("нашлось \([A-Za-z0-9<>]+\)", line):
+            repl = "'" + re.findall("\([A-Za-z0-9<>]+\)", tokenFound)[0][1:-1] + "' in string"
+
+            l = l.replace(tokenFound, repl)
+
+
+        for tokenReplace in re.findall("заменить \([A-Za-z0-9<>]+, [A-Za-z0-9<>]+\)", line):
+            fnd = re.findall("[A-Za-z0-9<>]+, [A-Za-z0-9<>]+", tokenReplace)[0].replace(', ', ',')
+
+            repl = "string.replace('" + fnd.split(',')[0] + "', '" + fnd.split(',')[1] + "')"
+
+            l = l.replace(tokenReplace, repl)
+
+        if "while" in l or "if" in l:
+            l += ":"
+
+        if len(l) != 0:
+            code.append(l)
+
+    if printCode:
+        for pl in code:
+            print(pl)
+
+    return code
